@@ -56,8 +56,9 @@ public:
 
     void jobFinished(int code, QProcess::ExitStatus status)
     {
-        if (status != QProcess::NormalExit)
+        if (status != QProcess::NormalExit) {
             qWarning() << "kdeconnect-cli crashed";
+        }
 
         setError(code);
         setOutput({{QStringLiteral("url"), QString()}});
